@@ -1,8 +1,7 @@
 ## Note: R CMD check may run these scripts from an installed package
 scripts <- list.files(system.file("scripts", package = "sm"), ".*\.q$")
 ## these need gam
-omit <- match(c("trwlgam1.q", "trwlgam2.q", "mackgam.q", "trwlgam3.q",
-                "smackgam.q"), scripts)
+omit <- match(c("trwlgam1.q", "trwlgam3.q"), scripts)
 ## these are interactive
 omit2 <- match(c("bissell3.q", "dogs.q"), scripts)
 scripts <- scripts[-c(omit, omit2)]
